Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(299)

Unified Diff: device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.cc

Issue 1954643002: DBus support for attribute properties and permissions. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@register_and_events
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.cc
diff --git a/device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.cc b/device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.cc
index 97f9882a045f68e679de2a430d6a1f573a1c42b0..b2eb66de12e8282577b97b735d72b6ed96d87750 100644
--- a/device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.cc
+++ b/device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.cc
@@ -18,7 +18,7 @@ FakeBluetoothGattDescriptorServiceProvider::
const dbus::ObjectPath& object_path,
std::unique_ptr<BluetoothGattAttributeValueDelegate> delegate,
const std::string& uuid,
- const std::vector<std::string>& permissions,
+ const std::vector<std::string>& flags,
const dbus::ObjectPath& characteristic_path)
: object_path_(object_path),
uuid_(uuid),
@@ -33,7 +33,7 @@ FakeBluetoothGattDescriptorServiceProvider::
DCHECK(base::StartsWith(object_path_.value(),
characteristic_path_.value() + "/",
base::CompareCase::SENSITIVE));
// TODO(armansito): Do something with |permissions|.
FakeBluetoothGattManagerClient* fake_bluetooth_gatt_manager_client =
static_cast<FakeBluetoothGattManagerClient*>(
« no previous file with comments | « device/bluetooth/dbus/fake_bluetooth_gatt_descriptor_service_provider.h ('k') | no next file » | no next file with comments »
@@ -33,7 +33,7 @@ FakeBluetoothGattDescriptorServiceProvider::
characteristic_path_.value() + "/",
base::CompareCase::SENSITIVE));
- // TODO(armansito): Do something with |permissions|.
+ // TODO(rkc): Do something with |flags|.
FakeBluetoothGattManagerClient* fake_bluetooth_gatt_manager_client =
static_cast<FakeBluetoothGattManagerClient*>(

Powered by Google App Engine
This is Rietveld 408576698